@@ -7,4 +7,7 @@
 /* Build with async support */
 #define SALSA_HAS_ASYNC_SUPPORT	1
 
+/* Enable deprecated attribute for non-working functions */
+#define SALSA_MARK_DEPRECATED	1
+
 #endif /* __ALSA_RECIPE_H */
