@@ -524,59 +524,59 @@ long snd_timer_status_get_queue(snd_timer_status_t * status)
 /*
  * not implemented
  */
-static inline __attribute__ ((deprecated))
+static inline __SALSA_NOT_IMPLEMENTED
 int snd_timer_query_open(snd_timer_query_t **handle, const char *name, int mode)
 {
 	return -ENXIO;
 }
 
-static inline __attribute__ ((deprecated))
+static inline __SALSA_NOT_IMPLEMENTED
 int snd_timer_query_open_lconf(snd_timer_query_t **handle, const char *name,
 			       int mode, snd_config_t *lconf)
 {
 	return -ENXIO;
 }
 
-static inline __attribute__ ((deprecated))
+static inline __SALSA_NOT_IMPLEMENTED
 int snd_timer_query_close(snd_timer_query_t *handle)
 {
 	return 0;
 }
 
-static inline __attribute__ ((deprecated))
+static inline __SALSA_NOT_IMPLEMENTED
 int snd_timer_query_next_device(snd_timer_query_t *handle, snd_timer_id_t *tid)
 {
 	return -ENXIO;
 }
 
-static inline __attribute__ ((deprecated))
+static inline __SALSA_NOT_IMPLEMENTED
 int snd_timer_query_info(snd_timer_query_t *handle, snd_timer_ginfo_t *info)
 {
 	return -ENXIO;
 }
 
-static inline __attribute__ ((deprecated))
+static inline __SALSA_NOT_IMPLEMENTED
 int snd_timer_query_params(snd_timer_query_t *handle,
 			   snd_timer_gparams_t *params)
 {
 	return -ENXIO;
 }
 
-static inline __attribute__ ((deprecated))
+static inline __SALSA_NOT_IMPLEMENTED
 int snd_timer_query_status(snd_timer_query_t *handle,
 			   snd_timer_gstatus_t *status)
 {
 	return -ENXIO;
 }
 
-static inline __attribute__ ((deprecated))
+static inline __SALSA_NOT_IMPLEMENTED
 int snd_timer_open_lconf(snd_timer_t **handle, const char *name, int mode,
 			 snd_config_t *lconf)
 {
 	return -ENXIO;
 }
 
-static inline __attribute__ ((deprecated))
+static inline __SALSA_NOT_IMPLEMENTED
 int snd_async_add_timer_handler(snd_async_handler_t **handler,
 				snd_timer_t *timer,
 				snd_async_callback_t callback,
@@ -585,7 +585,7 @@ int snd_async_add_timer_handler(snd_async_handler_t **handler,
 	return -ENXIO;
 }
 
-static inline __attribute__ ((deprecated))
+static inline __SALSA_NOT_IMPLEMENTED
 snd_timer_t *snd_async_handler_get_timer(snd_async_handler_t *handler)
 {
 	return NULL;
